#
# spec file for package libosmo-netif
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version_unconverted 0.4.0

Name:           libosmo-netif
Summary:        Osmocom library for muxed audio
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
Version:        0.4.0
Release:        lp151.1.1
Url:            https://osmocom.org/projects/libosmo-netif

Source:         %name-%version.tar.xz
Patch1:         osmo-talloc.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake
BuildRequires:  libtool >= 2
BuildRequires:  lksctp-tools-devel
BuildRequires:  pkg-config >= 0.20
BuildRequires:  xz
BuildRequires:  pkgconfig(libosmoabis) >= 0.6.0
BuildRequires:  pkgconfig(libosmocore) >= 1.0.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.0.0
BuildRequires:  pkgconfig(talloc)

%description
Network interface demuxer library for OsmoCom projects.

%package -n libosmonetif6
Summary:        Osmocom library for muxed audio
License:        AGPL-3.0-or-later
Group:          System/Libraries

%description -n libosmonetif6
Network interface demuxer library for OsmoCom projects.

%package -n libosmonetif-devel
Summary:        Development files for the Osmocom muxed audio library
License:        AGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmonetif6 = %version

%description -n libosmonetif-devel
Network interface demuxer library for OsmoCom projects.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-netif.

%prep
%setup -q
%patch -P 1 -p1

%build
echo "%version" >.tarball-version
autoreconf -fiv
%configure --enable-shared --disable-static --includedir="%_includedir/%name"
make %{?_smp_mflags}

%install
%make_install
find "%buildroot/%_libdir" -type f -name "*.la" -delete

%check
if ! make %{?_smp_mflags} check; then
	rv=$?
	cat tests/testsuite.log
	echo "Suppressing exit $rv"
	# timing issue
fi

%post   -n libosmonetif6 -p /sbin/ldconfig
%postun -n libosmonetif6 -p /sbin/ldconfig

%files -n libosmonetif6
%defattr(-,root,root)
%_libdir/libosmonetif.so.6*

%files -n libosmonetif-devel
%defattr(-,root,root)
%doc COPYING
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/netif/
%_libdir/libosmonetif.so
%_libdir/pkgconfig/libosmo-netif.pc

%changelog
* Wed Feb 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.4.0
  * Bugfix release only.
    The full changelog is available via
    http://git.osmocom.org/libosmo-netif/plain/debian/changelog?h=0.4.0
- Rebase patch
  * osmo-talloc.diff
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.3.0
  * stream: Avoid re-creating and leaking socket when unneeded
  * osmo_stream_{cli,srv}_destroy: fix a mem leak on an empty msgb queue
  * Add support for flushing and destroying a server-side stream
  * jibuf: Add initial implementation of Jitter Buffer
  * Remove "channel" layer
* Wed Dec 27 2017 jengelh@inai.de
- Update to new upstream release 0.1.1
  * cosmetic: relax UDP length check
  * cosmetic: print textual error from recv()
  * osmux_snprintf: Support different types of Osmux frames
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.85
  * rtp: return offset in osmo_rtp_snprintf()
  * somo_stream_srv_fd_cb(): close socket if NODELAY fails
* Fri Apr 28 2017 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.67
  * Fix potential NULL dereference
  * stream: don't crash in _close() when fd is not initialized
  * stream: When destroying, make sure to kill reconnect timer
  * osmux: Fix delay between RTP packets
* Sun Jul 31 2016 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.19
  * misc: Drop oRTP dependency as there is nothing using it
  * osmux: Pass circuit to _batch_del_circuit() and use it from _xfrm_input_fini()
  * osmux: Add function to delete all msgs pending for a circuit
  * osmux-test: remove real-time constraint by default
* Tue Jan 26 2016 jengelh@inai.de
- Dump testsuite results on failure
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream snapshot 0.0.6.8
  * don't link everything to libsctp
  * ensure to zero-initialize sctp_sndrcvinfo
* Wed Dec 23 2015 jengelh@inai.de
- Update to new upstream release 0.0.6.5
  * No changelog was provided
- Drop osmo-cppflags.diff, osmo-ldadd.diff, osmo-allincludes.diff
  (merged upstream)
* Thu Oct  2 2014 jengelh@inai.de
- Initial package (version 0.0.4) for build.opensuse.org
